api.authentication.v1.ldap.ldap_authenticate — Argus-Toolbelt 1.0 documentation

# Source code for api.authentication.v1.ldap.ldap_authenticate

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('authentication','v1','ldap','authenticate'))
    def authenticate(userName: str = None, domain: str = None, password: str = None,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Initiate a new user session using LDAP authentication (PUBLIC)
    Requires ldap authentication to be enabled on the server, and for the userUse /methods to check which authentication methods are available on the server.

        :param str userName: Username to authenticate
        :param str domain: User domain
        :param str password: LDAP password for user
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :returns: {"offset": 901, "limit": 245, "responseCode": 200, "count": 250, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Thought close society mention stay off field.", "messageTemplate": "Cover special lose drug.", "field": "Cold someone similar itself.", "parameter": {}, "timestamp": 619752182}], "currentPage": 451, "size": 285}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/ldap/authenticate".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if userName:
            body.update({"userName": userName})

        if domain:
            body.update({"domain": domain})

        if password:
            body.update({"password": password})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response